#' @importFrom R6 R6Class
NULL

times <- cli::symbol$times

._NULL_ <- logical()
attr(._NULL_, ".__NULL__") <- logical()


var_lab_row <- ".i"
var_lab_col <- ".j"
var_lab_mat <- ".m"

dots_for_names <- ".."
dots_for_names_expr <- "\\.\\."

join_opts <- c(default="left", "inner", "right", "full", "semi", "anti")
filt_join_opts <- c("semi", "anti")
adjust_opts <- c(x_only="pad_x", from_y="from_y")

